==> ksnuffle-0.1.tgz: ksnuffle-0.1/ksnuffle/knd_config.moc.cpp <==
/****************************************************************************
** KNDConf meta object code from reading C++ file 'knd_config.h'
**
** Created: Mon May 24 17:19:10 1999
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.11 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "knd_config.h"
#include <qmetaobject.h>


const char *KNDConf::className() const
{
    return "KNDConf";
}

QMetaObject *KNDConf::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_KNDConf(&KNDConf::staticMetaObject);

#endif

void KNDConf::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(QWidget::className(), "QWidget") != 0 )
	badSuperclassWarning("KNDConf","QWidget");

#if QT_VERSION >= 200
    staticMetaObject();
}

void KNDConf::staticMetaObject()
{
    if ( metaObj )
	return;
    QWidget::staticMetaObject();
#else

    QWidget::initMetaObject();
#endif

    typedef void(KNDConf::*m1_t0)();
    typedef void(KNDConf::*m1_t1)();
    typedef void(KNDConf::*m1_t2)();
    typedef void(KNDConf::*m1_t3)();
    typedef void(KNDConf::*m1_t4)();
    typedef void(KNDConf::*m1_t5)();
    m1_t0 v1_0 = &KNDConf::clickSet;
    m1_t1 v1_1 = &KNDConf::clickReset;
    m1_t2 v1_2 = &KNDConf::clickClear;
    m1_t3 v1_3 = &KNDConf::clickGo;
    m1_t4 v1_4 = &KNDConf::clickFreeze;
    m1_t5 v1_5 = &KNDConf::clickLog;
    QMetaData *slot_tbl = new QMetaData[6];
    slot_tbl[0].name = "clickSet()";
    slot_tbl[1].name = "clickReset()";
    slot_tbl[2].name = "clickClear()";
    slot_tbl[3].name = "clickGo()";
    slot_tbl[4].name = "clickFreeze()";
    slot_tbl[5].name = "clickLog()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    slot_tbl[2].ptr = *((QMember*)&v1_2);
    slot_tbl[3].ptr = *((QMember*)&v1_3);
    slot_tbl[4].ptr = *((QMember*)&v1_4);
    slot_tbl[5].ptr = *((QMember*)&v1_5);
    metaObj = new QMetaObject( "KNDConf", "QWidget",
	slot_tbl, 6,
	0, 0 );
}

==> ksnuffle-0.6.tgz: ksnuffle-0.6/ksnuffle/knd_config.moc.cpp <==
/****************************************************************************
** KNDConf meta object code from reading C++ file 'knd_config.h'
**
** Created: Tue Apr 25 08:41:16 2000
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.12 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "knd_config.h"
#include <qmetaobject.h>


const char *KNDConf::className() const
{
    return "KNDConf";
}

QMetaObject *KNDConf::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_KNDConf(&KNDConf::staticMetaObject);

#endif

void KNDConf::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(KNDPlugin::className(), "KNDPlugin") != 0 )
	badSuperclassWarning("KNDConf","KNDPlugin");

#if QT_VERSION >= 200
    staticMetaObject();
}

void KNDConf::staticMetaObject()
{
    if ( metaObj )
	return;
    KNDPlugin::staticMetaObject();
#else

    KNDPlugin::initMetaObject();
#endif

    typedef void(KNDConf::*m1_t0)();
    typedef void(KNDConf::*m1_t1)();
    typedef void(KNDConf::*m1_t2)();
    typedef void(KNDConf::*m1_t3)();
    typedef void(KNDConf::*m1_t4)();
    typedef void(KNDConf::*m1_t5)();
    typedef void(KNDConf::*m1_t6)();
    typedef void(KNDConf::*m1_t7)();
    m1_t0 v1_0 = &KNDConf::clickSet;
    m1_t1 v1_1 = &KNDConf::clickReset;
    m1_t2 v1_2 = &KNDConf::clickClear;
    m1_t3 v1_3 = &KNDConf::clickGo;
    m1_t4 v1_4 = &KNDConf::clickLog;
    m1_t5 v1_5 = &KNDConf::clickFreeze;
    m1_t6 v1_6 = &KNDConf::addPlugin;
    m1_t7 v1_7 = &KNDConf::remPlugin;
    QMetaData *slot_tbl = new QMetaData[8];
    slot_tbl[0].name = "clickSet()";
    slot_tbl[1].name = "clickReset()";
    slot_tbl[2].name = "clickClear()";
    slot_tbl[3].name = "clickGo()";
    slot_tbl[4].name = "clickLog()";
    slot_tbl[5].name = "clickFreeze()";
    slot_tbl[6].name = "addPlugin()";
    slot_tbl[7].name = "remPlugin()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    slot_tbl[2].ptr = *((QMember*)&v1_2);
    slot_tbl[3].ptr = *((QMember*)&v1_3);
    slot_tbl[4].ptr = *((QMember*)&v1_4);
    slot_tbl[5].ptr = *((QMember*)&v1_5);
    slot_tbl[6].ptr = *((QMember*)&v1_6);
    slot_tbl[7].ptr = *((QMember*)&v1_7);
    metaObj = new QMetaObject( "KNDConf", "KNDPlugin",
	slot_tbl, 8,
	0, 0 );
}
